import os
import sys
import click

@click.command(context_settings={"ignore_unknown_options": True})
@click.option("--console", default=False, is_flag=True, help="Use console UI instead of GUI")
@click.argument('args', nargs=-1)
def run(console, args):

    is_linux = sys.platform.startswith('linux')
    is_mac = sys.platform == 'darwin'
    is_windows = sys.platform in ['win32', 'cygwin']

    script_directory = os.path.dirname(os.path.abspath(__file__))

    if console:
        os.system(f"python {script_directory}/console_ui.py {' '.join(args)}")
    else:
        if is_linux or is_mac:
            if os.environ.get('DISPLAY') == '':
                print('No GUI, using console UI')
                os.system(f"python {script_directory}/console_ui.py {' '.join(args)}")
            else:
                print('Using GUI')
                os.system(f"python -m streamlit run {script_directory}/web_ui.py")
        elif is_windows:
            print('Using GUI')
            os.system(f"streamlit run {script_directory}/web_ui.py")
        else:
            print('Unknown platform, using console UI')
            os.system(f"python {script_directory}/console_ui.py {' '.join(args)}")

if __name__ == "__main__":
    run()


from fastapi import FastAPI
import uvicorn
from bot import MinecraftBot
import json
from fastapi.responses import JSONResponse
app = FastAPI()

config = {
  "server_ip": "menu.mc-complex.com", 
  "server_port": 25565,
  "bot_name": "silke2007minecraft@gmail.com",
  "password": "",  
  "auth": "microsoft",
  "version": "1.12",
  "viewer_port": 1000,
  "chest_coords": [10, 64, -8],
  "chest_range": 64,
  "chest_type": "chest",
  "items_name": "cobblestone",
  "items_count": 64,
  "x_coord": 0,
  "y_coord": 70, 
  "z_coord": 0
}

player = MinecraftBot(config, useReturn=True)

@app.get("/start")
async def startup():
    player.start()
    return JSONResponse(content={"message": "Bot started"})

@app.get("/inventory")
async def get_inventory():
    return JSONResponse(content={"inventory": player.inventory()})

@app.get("/coordinates") 
async def get_coordinates():
    return JSONResponse(content={"coordinates": player.coordinates()})

@app.get("/username")
async def get_username():
    return JSONResponse(content={"username": player.bot.username})

@app.get("/stop")
async def stop_bot():
    player.stop()
    return JSONResponse(content={"message": "Bot stopped"})

if __name__ == "__main__":
    uvicorn.run(app)